#######################################################################
#                                                                     #
#                                Sklml                                #
#                                                                     #
#                 The OCaml parallel skeleton system                  #
#                                                                     #
#                       EPI Serena, INRIA Paris                       #
#                                                                     #
#  Copyright (c) 2007-2017 INRIA.                                     #
#  Institut National de Recherche en Informatique et en Automatique.  #
#  All rights reserved. This file is distributed only by permission.  #
#                                                                     #
#  Quentin Carbonneaux                                                #
#  Francois Clement <Francois.Clement@inria.fr>                       #
#  Pierre Weis <Pierre.Weis@inria.fr>                                 #
#                                                                     #
#######################################################################

# $Id: Sklml_configure_additional_options.profile,v 1.23 2017/01/04 11:58:26 fclement Exp $

SKLML_COMPILER="False"
SKLML_DEP_GENERATOR="False"
SKLML_DOC_GENERATOR="False"
SKLML_PARALLEL_LAUNCHER="False"
SKLML_PARALLEL_LAUNCHER_DAEMON="False"
SKLML_COMMAND_SEARCH_PATH_FROM_COMMAND_LINE=""

sklml_print_additional_options_documentation () {
    SKLML_OPTIONS_TITLE="Sklml option"
    SKLML_OPTIONS_BODY=`\
        doc "--sklml-command-search-path" "-scsp" "path" \
            "Sklml command search path"`
    print_usage_section "$SKLML_OPTIONS_TITLE" "$SKLML_OPTIONS_BODY"
}

sklml_parse_additional_options () {
    UNPARSED_ARGUMENTS=""

    while test $# -gt 0; do

        case "$1" in

        # Sklml command search path.
        ( --sklml-command-search-path | -sklml-command-search-path | -scsp )
            VAL=`expand "$2"`; shift
            SKLML_COMMAND_SEARCH_PATH_FROM_COMMAND_LINE="$VAL"
            ;;

        ( * )
            if test -z "$UNPARSED_ARGUMENTS"; then
                UNPARSED_ARGUMENTS="$1"
            else
                UNPARSED_ARGUMENTS="$UNPARSED_ARGUMENTS $1"
            fi
            ;;

        esac

        shift

    done

    BINDINGS_TO_EXPORT="\
SKLML_COMMAND_SEARCH_PATH_FROM_COMMAND_LINE=\"\
$SKLML_COMMAND_SEARCH_PATH_FROM_COMMAND_LINE\""
    $ECHO "$UNPARSED_ARGUMENTS:$BINDINGS_TO_EXPORT"
}

sklml_process_additional_options () {
    CONFIGURE_SETTINGS_DIR="$1"
    CONFIGURE_SETTINGS_BASENAME="$2"

    report_message "Setting Sklml bindings in $RAD"

    if test -z "$SKLML_COMMAND_SEARCH_PATH"; then
        SKLML_COMMAND_SEARCH_PATH=`get_command_search_path`
        IER=$?
        if test $IER -ne 0; then exit $IER; fi
    fi
    if test -n "$SKLML_COMMAND_SEARCH_PATH_FROM_COMMAND_LINE"; then
        SKLML_COMMAND_SEARCH_PATH=`absolute_command_search_path \
            $SKLML_COMMAND_SEARCH_PATH_FROM_COMMAND_LINE`
        IER=$?
        if test $IER -ne 0; then exit $IER; fi
    fi

    for CMD in $PROJECT_OTHER_MANDATORY_COMMAND_LIST; do

        PROJECT_SKLML_COMMANDS_STATUS="Mandatory"

        case "${CMD:?}" in
        ( sklmlc )
            SKLML_COMPILER=`\
              get_command "${PROJECT_SKLML_COMMANDS_STATUS:?}"\
                          "$CMD" "$SKLML_COMPILER" ""\
                          "$SKLML_COMMAND_SEARCH_PATH" ""`
            IER=$?
            if test $IER -ne 0; then exit $IER; fi
            case "${SKLML_COMPILER:?}" in
            ( False | Not_found ) ;;
            ( */sklmlc* )
                SKLML_COMMAND_SEARCH_PATH=`$DIRNAME $SKLML_COMPILER` && \
                SKLML_WHERE=`$SKLML_COMPILER -where 2>&1`
                IER=$?
                if test $IER -ne 0; then exit $IER; fi
                SKLML_PPH_TEKNO_ROOT_DIR=`$SKLML_COMPILER -pph-tekno 2>&1`
                IER=$?
                if test $IER -ne 0; then exit $IER; fi
                SKLML_COMPILATION_TARGETS="byt bin"
                SKLML_COMPILATION_EXTENSIONS=".byt .bin"
                SKLML_LINK_TARGETS="seqbyt seqbin parbyt parbin"
                SKLML_LINK_EXTENSIONS=".seqbyt .seqbin .parbyt .parbin"
                ;;
            ( * )
                error "unsupported Sklml compiler \"$SKLML_COMPILER\""
                remedy "Please report."
                exit ${UNSUPPORTED_CASE_ERROR:?}
                ;;
            esac
            ;;

        ( sklmldep )
            SKLML_DEP_GENERATOR=`\
              get_command "${PROJECT_SKLML_COMMANDS_STATUS:?}"\
                          "$CMD" "$SKLML_DEP_GENERATOR" ""\
                          "$SKLML_COMMAND_SEARCH_PATH" ""`
            IER=$?
            if test $IER -ne 0; then exit $IER; fi
            ;;

        ( sklmldoc )
            SKLML_DOC_GENERATOR=`\
              get_command "${PROJECT_SKLML_COMMANDS_STATUS:?}"\
                          "$CMD" "$SKLML_DOC_GENERATOR" ""\
                          "$SKLML_COMMAND_SEARCH_PATH" ""`
            IER=$?
            if test $IER -ne 0; then exit $IER; fi
            ;;

        ( sklmlrun )
            SKLML_PARALLEL_LAUNCHER=`\
              get_command "${PROJECT_SKLML_COMMANDS_STATUS:?}"\
                          "$CMD" "$SKLML_PARALLEL_LAUNCHER" ""\
                          "$SKLML_COMMAND_SEARCH_PATH" ""`
            IER=$?
            if test $IER -ne 0; then exit $IER; fi
            ;;

        ( sklmlpard )
            SKLML_PARALLEL_LAUNCHER_DAEMON=`\
              get_command "${PROJECT_SKLML_COMMANDS_STATUS:?}"\
                          "$CMD" "$SKLML_PARALLEL_LAUNCHER_DAEMON" ""\
                          "$SKLML_COMMAND_SEARCH_PATH" ""`
            IER=$?
            if test $IER -ne 0; then exit $IER; fi
            ;;

        ( * )
            error "unknown Sklml command \"$CMD\"" >&2
            exit ${INVALID_VALUE_ERROR:?}
            ;;
        esac

    done

    # Store the current settings for Sklml commands.
    add_to_config_file \
        "${USER_CONFIGURE_SETTINGS_NO_EXT:?}" \
        "Sklml command search path" \
        "SKLML_COMMAND_SEARCH_PATH" "$SKLML_COMMAND_SEARCH_PATH" \
        "Sklml standard library location" "SKLML_WHERE" "$SKLML_WHERE" \
        "Sklml Pph tekno location" \
          "SKLML_PPH_TEKNO_ROOT_DIR" "$SKLML_PPH_TEKNO_ROOT_DIR" \
        "Sklml dependencies generator" \
          "SKLML_DEP_GENERATOR" "$SKLML_DEP_GENERATOR" \
        "Sklml documentation generator" \
          "SKLML_DOC_GENERATOR" "$SKLML_DOC_GENERATOR" \
        "Sklml compiler" "SKLML_COMPILER" "$SKLML_COMPILER" \
        "Sklml compilation targets" \
          "    SKLML_COMPILATION_TARGETS" "$SKLML_COMPILATION_TARGETS" \
        "Sklml compilation extensions" \
          "    SKLML_COMPILATION_EXTENSIONS" "$SKLML_COMPILATION_EXTENSIONS" \
        "Sklml link targets" \
          "    SKLML_LINK_TARGETS" "$SKLML_LINK_TARGETS" \
        "Sklml link extensions" \
          "    SKLML_LINK_EXTENSIONS" "$SKLML_LINK_EXTENSIONS" \
        "Sklml parallel launcher" \
          "SKLML_PARALLEL_LAUNCHER" "$SKLML_PARALLEL_LAUNCHER" \
        "Sklml parallel launcher daemon" \
          "SKLML_PARALLEL_LAUNCHER_DAEMON" "$SKLML_PARALLEL_LAUNCHER_DAEMON"
    IER=$?
    if test $IER -ne 0; then exit $IER; fi
}
