(***********************************************************************)
(*                                                                     *)
(*                                Sklml                                *)
(*                                                                     *)
(*                 The OCaml parallel skeleton system                  *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2007-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Quentin Carbonneaux                                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(*  This example is based on an example designed for OCamlP3l.         *)
(*                                                                     *)
(***********************************************************************)

(* $Id: make_dd2.ml,v 1.1 2017/01/05 16:23:14 fclement Exp $ *)

module Nat = Unatural;;
module L = Ulist;;
module U = Uunix;;

let _0_ = Nat._0_
and _1_ = Nat._1_
and _2_ = Nat._2_
;;

open Rdec2;;
open Subdomain;;
open Dd_config;;
open Make_dd1;;

let set_data = set_data;;

let subdomain_worker cfg ({ number = i; _; } as subd) =
  let io_ref = ref None
  and iter = ref _1_ in
  fun l ->
    let inmax = cfg.inner_itermax in
    let w_cmd = Filename.concat cfg.worker_dir cfg.worker_exe in
    let io = U.spawn_init (init_poisson subd inmax) w_cmd io_ref in
    let neighbors = L.map (fun (i, subd) -> (i, subd.bd)) (L.tl l) in
    let cur_bd = make_zero_boundary (size_of_boundary (snd (L.hd l)).bd) in
    let bd =
      normalize_boundary
        (L.fold_left (proj_boundary subd) cur_bd neighbors) in
    subd_send_msg cfg io !iter i bd;
    let res = subd_receive_result io (size_of_boundary bd) in
    Nat.incr iter;
    (res, res)
;;

let plot cfg rdec =
  let io_ref = ref None
  and iter = ref _1_ in
  fun v ->
    plot_send_msg cfg rdec io_ref !iter;
    Nat.incr iter;
    v
;;

let convergence cfg =
  let iter = ref _1_ in
  fun v ->
    conv_print_msg cfg v !iter;
    Nat.incr iter;
    !iter < cfg.outer_itermax
;;

let print_result = print_result;;
