(***********************************************************************)
(*                                                                     *)
(*                                Sklml                                *)
(*                                                                     *)
(*                 The OCaml parallel skeleton system                  *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2007-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Quentin Carbonneaux                                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: wrapper.ml,v 1.12 2017/01/04 11:58:31 fclement Exp $ *)

module Nat = Unatural;;
module Perv = Upervasives;;
module A = Uarray;;
module D = Udebug;;

let _0_ = Nat._0_
and _1_ = Nat._1_
;;

open Misc_sprint;;

let qual = Perv.qualify "Wrapper";;
let failwith = Perv.failwith_qual qual;;

(* Init. *)

let mk_init_inj { D.spf_report = report; _; } () =
  report "sending zero value";
  [||]
;;

let mk_init_proj { D.spf_report = report; spf_debug = debug; _; } vals =
  let nargs = A.length vals in
  if nargs <> _1_ then
    failwith "init_proj" "initialization should return one value" else
  (* Now, we have nargs = A.length vals = 1.
     Therefore, the next A.unsafe_get will be safe. *)
  report "one value received";
  let l = A.to_list (Typed_value.to_int_vector (A.unsafe_get vals _0_)) in
  report "integer list extracted";
  debug (sprint_int_list "l" l);
  l
;;

let make_init_wrapper =
  Pio.make_task_wrapper "init" mk_init_inj mk_init_proj
;;

(* Comp. *)

let mk_comp_inj { D.spf_report = report; spf_debug = debug; _; } i =
  report "sending one value";
  report "sending integer";
  debug (sprint_int "i" i);
  [| Typed_value.of_int i; |]
;;

let mk_comp_proj { D.spf_report = report; spf_debug = debug; _; } vals =
  let nargs = A.length vals in
  if nargs <> _1_ then
    failwith "comp_proj" "computation should return one value" else
  (* Now, we have nargs = A.length vals = 1.
     Therefore, the next A.unsafe_get will be safe. *)
  report "one value received";
  let i' = Typed_value.to_int (A.unsafe_get vals _0_) in
  report "integer extracted";
  debug (sprint_int "i'" i');
  i'
;;

let make_light_comp_wrapper =
  Pio.make_task_wrapper "light comp" mk_comp_inj mk_comp_proj
;;

let make_heavy_comp_wrapper =
  Pio.make_task_wrapper "heavy comp" mk_comp_inj mk_comp_proj
;;

(* Final. *)

let mk_final_inj { D.spf_report = report; _; } () =
  report "sending zero value";
  [||]
;;

let mk_final_proj { D.spf_report = report; spf_debug = debug; _; } vals =
  let nargs = A.length vals in
  if nargs <> _1_ then
    failwith "final_proj" "finalization should return one value" else
  (* Now, we have nargs = A.length vals = 1.
     Therefore, the next A.unsafe_get will be safe. *)
  report "one value received";
  let msg = Typed_value.to_string (A.unsafe_get vals _0_) in
  debug (format_sprint Og_printer.printer_String "msg" msg);
  if msg <> "OK, bye!" then
    failwith "final_proj" "finalization should return \"OK, bye!\"" else
  report "farewell message extracted";
;;

let make_final_wrapper =
  Pio.make_task_wrapper "final" mk_final_inj mk_final_proj
;;
