(***********************************************************************)
(*                                                                     *)
(*                                Sklml                                *)
(*                                                                     *)
(*                 The OCaml parallel skeleton system                  *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2007-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Quentin Carbonneaux                                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: IO.mli,v 1.14 2017/01/04 11:58:27 fclement Exp $ *)

open Tools_common_types;;

type ic;;
type oc;;

type t = ic * oc
and io = t
;;

type perms = Unatural.t;;

type fork_data =
  | Child
  | Parent of pid
;;

exception IOError of string;;

val stdin : ic;;
val stdout : oc;;

val ioerr : string -> 'a;;
val read_sockaddr : string -> Unix.sockaddr;;
val dump_sockaddr : unit -> Unix.sockaddr -> string;;
val print_sockaddr : out_channel -> Unix.sockaddr -> unit;;
val get_port : Unix.sockaddr -> port;;
val create_bound_socket : port option -> Unix.file_descr * Unix.sockaddr;;
val connect : Unix.sockaddr -> t;;
val close_in : ic -> unit;;
val close_out : oc -> unit;;
val connect_fd : Unix.sockaddr -> Unix.file_descr;;
val of_channel : ic -> 'a;;
val to_channel : oc -> 'a -> bool -> unit;;
val in_channel_of_ic : ic -> in_channel;;
val out_channel_of_oc : oc -> out_channel;;
val wait_connection : Unix.file_descr -> bool -> t * Unix.inet_addr;;
val fork : unit -> fork_data;;
val open_process : string -> t;;
val open_process_in : string -> ic;;
val open_in_out : string -> t;;
val open_in : string -> ic;;
val open_default_perms : perms;;
val open_out : string -> oc;;
val pipe : unit -> t;;
val fifo_default_perms : perms;;
val openfifo_in : string -> ic;;
val openfifo_out : string -> oc;;
