(***********************************************************************)
(*                                                                     *)
(*                                Sklml                                *)
(*                                                                     *)
(*                 The OCaml parallel skeleton system                  *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2007-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Quentin Carbonneaux                                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: options.ml,v 1.22 2017/05/15 17:29:20 fclement Exp $ *)

module Opts = Tools_options;;

open Tools_common_types;;

(* Command-line options. *)

let command_kind = "compiler"
and command_suffix = "c"
;;

let oks =
  [
   Opts.semantics_mode_ok;
   Opts.compilation_mode_ok;
   Opts.sklml_install_root_dir_ok;
   Opts.sklml_lib_root_dir_ok;
   Opts.sklml_pph_tekno_dir_ok;
  ]

and rcos =
  [
   Opts.semantics_mode_rco;
   Opts.compilation_mode_rco;
   Opts.sklml_install_root_dir_rco;
   Opts.sklml_lib_root_dir_rco;
   Opts.sklml_pph_tekno_dir_rco;
  ]
;;

let doc_mandatory_arguments = "-mode {seq|par} ";;

let (command_title, phase) =
  Opts.set_command_line_options
    command_kind command_suffix
    oks rcos
    doc_mandatory_arguments
;;

(* Report/debug flags and warning/error messages. *)

let services =
  Opts.add_services Sklml_version.option_key_data_no_prefix command_title
;;

(* Parsing the command line. *)

type t =
  {
   compilation_mode : compilation_mode;
   semantics_mode : semantics_mode;
   lib_root_dir : root_dir;
   ocaml_options : string list;
  }
and options = t
;;

let get_options argv =
  {
   compilation_mode = Opts.get_compilation_mode ();
   semantics_mode = Opts.get_semantics_mode ();
   lib_root_dir = Opts.get_sklml_lib_root_dir ();
   ocaml_options = Opts.get_ocaml_options argv;
  }
;;

let parse () = Opts.parse services phase get_options;;
