(***********************************************************************)
(*                                                                     *)
(*                                Sklml                                *)
(*                                                                     *)
(*                 The OCaml parallel skeleton system                  *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2007-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Quentin Carbonneaux                                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: spawnlib.ml,v 1.37 2017/01/04 11:58:29 fclement Exp $ *)

module Nat = Unatural;;

let _1_ = Nat._1_;;

open Tools_common_types;;

let { tagged_debug = debug; _; } = Options.services;;

let debug fname = debug (Printf.sprintf "Spawnlib.%s" fname);;

(* Tools *)

let not_impl () = failwith "Not implemented yet";;

let fail msg =
  Log.say Log.Err "%s" msg;
  exit 2
;;

let maybe x err f =
  match x with
  | None -> err ()
  | Some x -> f x
;;

(* Process management *)

let install_sighandlers _x = not_impl ();;

let spawn_sock f x =
  let (sock, addr) = IO.create_bound_socket None in
  Unix.listen sock 1;
  match IO.fork () with
  | IO.Child -> f (fst (IO.wait_connection sock true)) x; exit 0
  | IO.Parent _ -> Unix.close sock; IO.get_port addr
;;

(* Master-slave communications *)

type ('state, 'req) request_handler = 'req -> 'state;;
type ('state, 'req) request_generator = 'state -> 'req option;;

let request_slave (ic, oc) req =
  IO.to_channel oc req true;
  let rep = IO.of_channel ic in
  rep
;;

let slave_loop (ic, oc) req_handler =
  let debug = debug "slave_loop" in
  debug "entering";
  let rec loop () =
    try
      let req = IO.of_channel ic in
      IO.to_channel oc (req_handler req) true;
      loop ()
    with
    | End_of_file ->
      Log.say (Log.Log _1_) "Connection closed by the master node.";
      debug "leaving" in
  loop ()
;;

let master_loop req_gen req_handler s =
  let debug = debug "master_loop" in
  debug "entering";
  let rec loop s =
    match req_gen s with
    | None -> debug "leaving"; s
    | Some req ->
      let nstate = req_handler req in
      loop nstate in
  loop s
;;
