(***********************************************************************)
(*                                                                     *)
(*                                Sklml                                *)
(*                                                                     *)
(*                 The OCaml parallel skeleton system                  *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2007-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Quentin Carbonneaux                                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: batch.mli,v 1.24 2017/01/04 11:58:30 fclement Exp $ *)

open Tools_common_types;;

type t
and batch = t
(** The hidden type of batches. *)
;;

type fail_action =
  | Fail_error of string
  | Fail_ignore
  | Fail_warn of string
;;

type task_type =
  | Background
  | Normal
  | Timeouted of timeout
;;

type shell_action =
  {
   program : string;
   args : string array;
  }
;;

type batch_error =
  | Batch_failure
  | Batch_shell_error of return_code * shell_action
  | Batch_timeout of shell_action
;;

type batch_run_return =
  | Sklml_Error of pid list * batch_error
  | Sklml_Ok of pid list
;;

val empty : t;;

val add_shell_task : t -> fail_action -> shell_action -> task_type -> t;;
val add_subscript_task : t -> fail_action -> t -> t;;
val add_pipe_task : t -> fail_action -> t -> (in_channel -> t) -> t;;
val add_control_task : t -> fail_action -> (pid list -> t) -> t;;
val add_echo_task : t -> string -> t;;
val add_fail_task : t -> string -> t;;

val eval_batch : t -> out_channel -> out_channel -> batch_run_return;;
