(***********************************************************************)
(*                                                                     *)
(*                                Sklml                                *)
(*                                                                     *)
(*                 The OCaml parallel skeleton system                  *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2007-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Quentin Carbonneaux                                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* Beginning of OCamlGen, 4.2+dev0 generated code. *)

let rec printer_index ctx ppf = function
  | u_i -> Upervasives_print.printer_index ctx ppf u_i

and printer_length ctx ppf = function
  | u_l -> Upervasives_print.printer_length ctx ppf u_l

and printer_number_of_workers ctx ppf = function
  | l -> printer_length ctx ppf l

and printer_offset ctx ppf = function
  | u_o -> Upervasives_print.printer_offset ctx ppf u_o

and printer_pid ctx ppf = function
  | u_t -> Unatural_print.printer_t ctx ppf u_t

and printer_port ctx ppf = function
  | u_t -> Unatural_print.printer_t ctx ppf u_t

and printer_return_code ctx ppf = function
  | u_t -> Unatural_print.printer_t ctx ppf u_t

and printer_size ctx ppf = function | l -> printer_length ctx ppf l

and printer_timeout ctx ppf = function
  | u_t -> Unatural_print.printer_t ctx ppf u_t

and printer_worker_index ctx ppf = function | i -> printer_index ctx ppf i
;;

let printer_color ctx ppf = function | i -> Og_printer.printer_Int ctx ppf i
;;

let rec printer_command ctx ppf = function
  | s -> Og_printer.printer_String ctx ppf s

and printer_command_kind ctx ppf = function
  | s -> Og_printer.printer_String ctx ppf s

and printer_command_suffix ctx ppf = function | s -> printer_suffix ctx ppf s

and printer_command_title ctx ppf = function
  | s -> Og_printer.printer_String ctx ppf s

and printer_doc_mandatory_arguments ctx ppf = function
  | s -> Og_printer.printer_String ctx ppf s

and printer_inc ctx ppf = function | p -> printer_path ctx ppf p

and printer_lib ctx ppf = function | p -> printer_path ctx ppf p

and printer_option_key ctx ppf = function
  | s -> Og_printer.printer_String ctx ppf s

and printer_path ctx ppf = function
  | s -> Og_printer.printer_String ctx ppf s

and printer_root_dir ctx ppf = function | p -> printer_path ctx ppf p

and printer_suffix ctx ppf = function
  | s -> Og_printer.printer_String ctx ppf s
;;

let printer_semantics_mode _ctx ppf = function
  | Tools_common_types.Seq ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Seq"
  | Tools_common_types.Par ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Par"
;;

let printer_compilation_mode _ctx ppf = function
  | Tools_common_types.Byt ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Byt"
  | Tools_common_types.Bin ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Bin"
;;

let printer_generator_kind _ctx ppf = function
  | Tools_common_types.Dep ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Dep"
  | Tools_common_types.Doc ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Doc"
;;

let printer_message_print ctx ppf = function
  | f_u_m_u ->
    Og_printer.printer_Fun
      Upervasives_print.printer_message
      Og_printer.printer_Unit
      ctx
      ppf
      f_u_m_u

and printer_gen_message_print ctx ppf = function
  | f_u_g_u ->
    Og_printer.printer_Fun
      Upervasives_print.printer_gen_message
      Og_printer.printer_Unit
      ctx
      ppf
      f_u_g_u
;;

let printer_report ctx ppf = function | m -> printer_message_print ctx ppf m

and printer_report_action ctx ppf = function
  | g -> printer_gen_message_print ctx ppf g

and printer_debug ctx ppf = function | m -> printer_message_print ctx ppf m

and printer_debug_action ctx ppf = function
  | g -> printer_gen_message_print ctx ppf g

and printer_warning ctx ppf = function | m -> printer_message_print ctx ppf m

and printer_error pp_a ctx ppf = function
  | f_u_m_f_r_a ->
    Og_printer.printer_Fun
      Upervasives_print.printer_message
      (Og_printer.printer_Fun printer_return_code pp_a)
      ctx
      ppf
      f_u_m_f_r_a
;;

let printer_services pp_a ctx ppf = function
  | {
      Tools_common_types.report = r;
      Tools_common_types.debug = d;
      Tools_common_types.error = a_e;
    } ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%, {@ " else
    Format.fprintf ppf "%,@[<hv 2>{@ "; Format.fprintf ppf "%,@[<hv 0>";
    Format.fprintf ppf "%,@[<hv 2>report =";
    printer_report Og_precedence.Ck_record_field ppf r;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>debug =";
    printer_debug Og_precedence.Ck_record_field ppf d;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>error =";
    printer_error pp_a Og_precedence.Ck_record_field ppf a_e;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@;<1 -2>}" else
    Format.fprintf ppf "%,@;<1 -2>}@]"
;;

let printer_tagged_report ctx ppf = function | r -> printer_report ctx ppf r

and printer_tagged_report_action ctx ppf = function
  | r -> printer_report_action ctx ppf r

and printer_tagged_debug ctx ppf = function
  | f_u_f_d ->
    Og_printer.printer_Fun
      Upervasives_print.printer_function_name
      printer_debug
      ctx
      ppf
      f_u_f_d

and printer_tagged_debug_action ctx ppf = function
  | f_u_f_d ->
    Og_printer.printer_Fun
      Upervasives_print.printer_function_name
      printer_debug_action
      ctx
      ppf
      f_u_f_d

and printer_tagged_warning ctx ppf = function
  | w -> printer_warning ctx ppf w

and printer_tagged_error pp_a ctx ppf = function
  | f_u_m_a ->
    Og_printer.printer_Fun Upervasives_print.printer_message pp_a
      ctx
      ppf
      f_u_m_a
;;

let printer_tagged_services pp_a ctx ppf = function
  | {
      Tools_common_types.tagged_report = t;
      Tools_common_types.tagged_report_action = t0;
      Tools_common_types.tagged_debug = t1;
      Tools_common_types.tagged_debug_action = t2;
      Tools_common_types.tagged_warning = t3;
      Tools_common_types.tagged_error = a_t;
    } ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%, {@ " else
    Format.fprintf ppf "%,@[<hv 2>{@ "; Format.fprintf ppf "%,@[<hv 0>";
    Format.fprintf ppf "%,@[<hv 2>tagged_report =";
    printer_tagged_report Og_precedence.Ck_record_field ppf t;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>tagged_report_action =";
    printer_tagged_report_action Og_precedence.Ck_record_field ppf t0;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>tagged_debug =";
    printer_tagged_debug Og_precedence.Ck_record_field ppf t1;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>tagged_debug_action =";
    printer_tagged_debug_action Og_precedence.Ck_record_field ppf t2;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>tagged_warning =";
    printer_tagged_warning Og_precedence.Ck_record_field ppf t3;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>tagged_error =";
    printer_tagged_error pp_a Og_precedence.Ck_record_field ppf a_t;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@;<1 -2>}" else
    Format.fprintf ppf "%,@;<1 -2>}@]"
;;

(* Defining top printers. *)

let print_index ppf = printer_index Og_precedence.Ck_toplevel ppf

and print_length ppf = printer_length Og_precedence.Ck_toplevel ppf

and print_number_of_workers ppf =
  printer_number_of_workers Og_precedence.Ck_toplevel ppf

and print_offset ppf = printer_offset Og_precedence.Ck_toplevel ppf

and print_pid ppf = printer_pid Og_precedence.Ck_toplevel ppf

and print_port ppf = printer_port Og_precedence.Ck_toplevel ppf

and print_return_code ppf = printer_return_code Og_precedence.Ck_toplevel ppf

and print_size ppf = printer_size Og_precedence.Ck_toplevel ppf

and print_timeout ppf = printer_timeout Og_precedence.Ck_toplevel ppf

and print_worker_index ppf =
  printer_worker_index Og_precedence.Ck_toplevel ppf
;;

let print_color ppf = printer_color Og_precedence.Ck_toplevel ppf
;;

let print_command ppf = printer_command Og_precedence.Ck_toplevel ppf

and print_command_kind ppf =
  printer_command_kind Og_precedence.Ck_toplevel ppf

and print_command_suffix ppf =
  printer_command_suffix Og_precedence.Ck_toplevel ppf

and print_command_title ppf =
  printer_command_title Og_precedence.Ck_toplevel ppf

and print_doc_mandatory_arguments ppf =
  printer_doc_mandatory_arguments Og_precedence.Ck_toplevel ppf

and print_inc ppf = printer_inc Og_precedence.Ck_toplevel ppf

and print_lib ppf = printer_lib Og_precedence.Ck_toplevel ppf

and print_option_key ppf = printer_option_key Og_precedence.Ck_toplevel ppf

and print_path ppf = printer_path Og_precedence.Ck_toplevel ppf

and print_root_dir ppf = printer_root_dir Og_precedence.Ck_toplevel ppf

and print_suffix ppf = printer_suffix Og_precedence.Ck_toplevel ppf
;;

let print_semantics_mode ppf =
  printer_semantics_mode Og_precedence.Ck_toplevel ppf
;;

let print_compilation_mode ppf =
  printer_compilation_mode Og_precedence.Ck_toplevel ppf
;;

let print_generator_kind ppf =
  printer_generator_kind Og_precedence.Ck_toplevel ppf
;;

let print_message_print ppf =
  printer_message_print Og_precedence.Ck_toplevel ppf

and print_gen_message_print ppf =
  printer_gen_message_print Og_precedence.Ck_toplevel ppf
;;

let print_report ppf = printer_report Og_precedence.Ck_toplevel ppf

and print_report_action ppf =
  printer_report_action Og_precedence.Ck_toplevel ppf

and print_debug ppf = printer_debug Og_precedence.Ck_toplevel ppf

and print_debug_action ppf =
  printer_debug_action Og_precedence.Ck_toplevel ppf

and print_warning ppf = printer_warning Og_precedence.Ck_toplevel ppf

and print_error pp_a ppf = printer_error pp_a Og_precedence.Ck_toplevel ppf
;;

let print_services pp_a ppf =
  printer_services pp_a Og_precedence.Ck_toplevel ppf
;;

let print_tagged_report ppf =
  printer_tagged_report Og_precedence.Ck_toplevel ppf

and print_tagged_report_action ppf =
  printer_tagged_report_action Og_precedence.Ck_toplevel ppf

and print_tagged_debug ppf =
  printer_tagged_debug Og_precedence.Ck_toplevel ppf

and print_tagged_debug_action ppf =
  printer_tagged_debug_action Og_precedence.Ck_toplevel ppf

and print_tagged_warning ppf =
  printer_tagged_warning Og_precedence.Ck_toplevel ppf

and print_tagged_error pp_a ppf =
  printer_tagged_error pp_a Og_precedence.Ck_toplevel ppf
;;

let print_tagged_services pp_a ppf =
  printer_tagged_services pp_a Og_precedence.Ck_toplevel ppf
;;

(* End of OCamlGen, 4.2+dev0 generated code. *)
